package com.qmth.distributed.print.api;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.backup.MySQLDatabaseBackup;
import com.qmth.distributed.print.business.bean.params.SysAdminSetParam;
import com.qmth.distributed.print.business.bean.result.CustomPrivilegeResult;
import com.qmth.distributed.print.business.bean.result.SysAdminSetResult;
import com.qmth.teachcloud.common.bean.dto.PrivilegeDto;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.entity.*;
import com.qmth.teachcloud.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.common.service.*;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.security.NoSuchAlgorithmException;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @Description: 超管设置
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/10/29
 */
@Api(tags = "超管设置Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_SET)
//@Aac(auth = BOOL.FALSE, strict = BOOL.FALSE)
public class SysAdminSetController {

    @Resource
    SysPrivilegeService sysPrivilegeService;

    @Resource
    TSchoolPrivilegeService tSchoolPrivilegeService;

    @Resource
    SysRolePrivilegeService sysRolePrivilegeService;

    @Resource
    SysRoleService sysRoleService;

    @Resource
    CommonCacheService commonCacheService;

    @Resource
    SysUserRoleService sysUserRoleService;

    @Resource
    TeachcloudCommonService commonService;

    @Resource
    SysConfigService sysConfigService;

    @Resource
    MySQLDatabaseBackup mySQLDatabaseBackup;

    @Resource
    TSchoolRoleService tSchoolRoleService;

    @ApiOperation(value = "数据还原")
    @ApiResponses({@ApiResponse(code = 200, message = "数据还原信息", response = ResultUtil.class)})
    @RequestMapping(value = "/backup", method = RequestMethod.POST)
    public Result sysadminBackup(@ApiParam(value = "学校id ", required = true) @RequestParam Long schoolId) throws Exception {
        mySQLDatabaseBackup.exportDatabaseTool();
        mySQLDatabaseBackup.deleteDbTool(SystemConstant.PRINT_DELETE_DATA_FILE_NAME, schoolId);
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "同步配置查询")
    @ApiResponses({@ApiResponse(code = 200, message = "同步配置信息", response = SysAdminSetResult.class)})
    @RequestMapping(value = "/sync/select", method = RequestMethod.POST)
    public Result sysadminSyncSelect(@ApiParam(value = "学校id ", required = true) @RequestParam Long schoolId) {
        SysConfig sysConfigSyncServicePath = commonCacheService.addSysConfigCache(schoolId, SystemConstant.SYNC_SERVICE_PATH);
        String syncServicePath = null;
        if (Objects.nonNull(sysConfigSyncServicePath)) {
            syncServicePath = sysConfigSyncServicePath.getConfigValue();
        } else {
            JSONObject jsonObject = new JSONObject();
            jsonObject.put(SystemConstant.QUESTION_HOST_URL, "");
            jsonObject.put(SystemConstant.CLOUDMARK_HOST_URL, "");
            jsonObject.put(SystemConstant.TEACHCLOUD_REPORT_HOST_URL, "");
            syncServicePath = jsonObject.toString();
        }
        return ResultUtil.ok(new SysAdminSetResult(schoolId, syncServicePath));
    }

    @ApiOperation(value = "同步配置保存")
    @ApiResponses({@ApiResponse(code = 200, message = "同步配置信息", response = ResultUtil.class)})
    @RequestMapping(value = "/sync/save", method = RequestMethod.POST)
    @Transactional
    public Result sysadminSyncSave(@Valid @RequestBody SysAdminSetParam sysAdminSetParam, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        Optional.ofNullable(sysAdminSetParam.getSyncServicePath()).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("同步配置地址不能为空"));

        SysConfig sysConfigSyncServicePath = commonCacheService.addSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.SYNC_SERVICE_PATH);
        if (Objects.isNull(sysConfigSyncServicePath)) {
            sysConfigSyncServicePath = new SysConfig(sysAdminSetParam.getSchoolId(), SystemConstant.SYNC_SERVICE_PATH, "同步配置地址", sysAdminSetParam.getSyncServicePath());
            JSONObject jsonObject = JSONObject.parseObject(sysConfigSyncServicePath.getConfigValue());
            SysConfig sysConfigQuestionHostUrl = commonCacheService.addSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.QUESTION_HOST_URL);
            sysConfigQuestionHostUrl.setConfigValue(jsonObject.getString(SystemConstant.QUESTION_HOST_URL));

            SysConfig sysConfigCloudmarkHostUrl = commonCacheService.addSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.CLOUDMARK_HOST_URL);
            sysConfigCloudmarkHostUrl.setConfigValue(jsonObject.getString(SystemConstant.CLOUDMARK_HOST_URL));

            SysConfig sysConfigTeachcloudReportHostUrl = commonCacheService.addSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.TEACHCLOUD_REPORT_HOST_URL);
            sysConfigQuestionHostUrl.setConfigValue(jsonObject.getString(SystemConstant.TEACHCLOUD_REPORT_HOST_URL));

            sysConfigService.saveOrUpdateBatch(Arrays.asList(sysConfigQuestionHostUrl, sysConfigCloudmarkHostUrl, sysConfigTeachcloudReportHostUrl));

            commonCacheService.updateSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.QUESTION_HOST_URL);
            commonCacheService.updateSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.CLOUDMARK_HOST_URL);
            commonCacheService.updateSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.TEACHCLOUD_REPORT_HOST_URL);
        } else {
            sysConfigSyncServicePath.setConfigValue(sysAdminSetParam.getSyncServicePath());
        }
        sysConfigService.saveOrUpdate(sysConfigSyncServicePath);

        commonCacheService.updateSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.SYNC_SERVICE_PATH);
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "系统试卷规格配置查询")
    @ApiResponses({@ApiResponse(code = 200, message = "系统试卷规格配置信息", response = CustomPrivilegeResult.class)})
    @RequestMapping(value = "/paper/sys/select", method = RequestMethod.POST)
    public Result sysadminPaperSysSelect() {
        SysConfig sysConfig = commonCacheService.addSysConfigCache(SystemConstant.SYS_PDF_SIZE_LIST);
        Optional.ofNullable(sysConfig).orElseThrow(() -> ExceptionResultEnum.ERROR.exception("未配置全局pdf格式清单"));
        CustomPrivilegeResult customPrivilegeResult = new CustomPrivilegeResult();
        customPrivilegeResult.setSysPdfSize(Arrays.asList(sysConfig.getConfigValue().replaceAll("\\[", "").replaceAll("\\]", "").split(", ")));
        return ResultUtil.ok(customPrivilegeResult);
    }

    @ApiOperation(value = "试卷规格配置查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷规格配置信息", response = SysAdminSetResult.class)})
    @RequestMapping(value = "/paper/select", method = RequestMethod.POST)
    public Result sysadminPaperSelect(@ApiParam(value = "学校id ", required = true) @RequestParam Long schoolId) {
        SysConfig sysConfigPdfSize = commonCacheService.addSysConfigCache(schoolId, SystemConstant.PDF_SIZE_LIST);
        List<String> pdfSize = null;
        if (Objects.nonNull(sysConfigPdfSize)) {
            pdfSize = Arrays.asList(sysConfigPdfSize.getConfigValue().replaceAll("\\[", "").replaceAll("\\]", "").split(", "));
        }
        SysAdminSetResult sysAdminSetResult = new SysAdminSetResult();
        sysAdminSetResult.setSchoolId(schoolId);
        sysAdminSetResult.setPdfSize(CollectionUtils.isEmpty(pdfSize) ? new ArrayList<>() : pdfSize);
        return ResultUtil.ok(sysAdminSetResult);
    }

    @ApiOperation(value = "试卷规格配置保存")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷规格配置信息", response = ResultUtil.class)})
    @RequestMapping(value = "/paper/save", method = RequestMethod.POST)
    @Transactional
    public Result sysadminPaperSave(@Valid @RequestBody SysAdminSetParam sysAdminSetParam, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        Optional.ofNullable(sysAdminSetParam.getPdfSize()).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("试卷规格配置不能为空"));

        SysConfig sysConfigPdfSize = commonCacheService.addSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.PDF_SIZE_LIST);
        if (Objects.isNull(sysConfigPdfSize)) {
            sysConfigPdfSize = new SysConfig(sysAdminSetParam.getSchoolId(), SystemConstant.PDF_SIZE_LIST, "pdf格式清单", Arrays.asList(sysAdminSetParam.getPdfSize()).toString());
        } else {
            if (Objects.nonNull(sysAdminSetParam.getPdfSize()) && sysAdminSetParam.getPdfSize().length > 0) {
                sysConfigPdfSize.setConfigValue(Arrays.asList(sysAdminSetParam.getPdfSize()).toString());
            } else {
                sysConfigPdfSize.setConfigValue(null);
            }
        }
        sysConfigService.saveOrUpdate(sysConfigPdfSize);

        commonCacheService.updateSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.PDF_SIZE_LIST);
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "用户验证查询")
    @ApiResponses({@ApiResponse(code = 200, message = "用户验证信息", response = SysAdminSetResult.class)})
    @RequestMapping(value = "/user/select", method = RequestMethod.POST)
    public Result sysadminUserSelect(@ApiParam(value = "学校id ", required = true) @RequestParam Long schoolId) {
        SysConfig sysConfigAccount = commonCacheService.addSysConfigCache(schoolId, SystemConstant.ACCOUNT_SMS_VERIFY);
        SysConfig sysConfigTeachcloudExchangeSerivePath = commonCacheService.addSysConfigCache(schoolId, SystemConstant.TEACHCLOUD_EXCHANGE_HOST_URL);
        return ResultUtil.ok(new SysAdminSetResult(schoolId, Objects.nonNull(sysConfigAccount) ? Boolean.valueOf(sysConfigAccount.getConfigValue()) : false, Objects.nonNull(sysConfigTeachcloudExchangeSerivePath) ? sysConfigTeachcloudExchangeSerivePath.getConfigValue() : ""));
    }

    @ApiOperation(value = "用户验证保存")
    @ApiResponses({@ApiResponse(code = 200, message = "用户验证信息", response = ResultUtil.class)})
    @RequestMapping(value = "/user/save", method = RequestMethod.POST)
    @Transactional
    public Result sysadminUserSave(@Valid @RequestBody SysAdminSetParam sysAdminSetParam, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        Optional.ofNullable(sysAdminSetParam.getAccountSmsVerify()).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("用户/密码模式是否开启不能为空"));
        Optional.ofNullable(sysAdminSetParam.getTeachcloudExchangeSerivePath()).orElseThrow(() -> ExceptionResultEnum.PARAMS_ERROR.exception("第三方统一身份认证不能为空"));

        List<SysConfig> sysConfigList = new ArrayList<>();
        SysConfig sysConfigAccount = commonCacheService.addSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.ACCOUNT_SMS_VERIFY);
        if (Objects.isNull(sysConfigAccount)) {
            sysConfigAccount = new SysConfig(sysAdminSetParam.getSchoolId(), SystemConstant.ACCOUNT_SMS_VERIFY, "用户/密码模式是否开启短信验证", String.valueOf(sysAdminSetParam.getAccountSmsVerify()));
        } else {
            sysConfigAccount.setConfigValue(String.valueOf(sysAdminSetParam.getAccountSmsVerify()));
        }
        sysConfigList.add(sysConfigAccount);

        SysConfig sysConfigTeachcloudExchangeSerivePath = commonCacheService.addSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.TEACHCLOUD_EXCHANGE_HOST_URL);
        if (Objects.isNull(sysConfigTeachcloudExchangeSerivePath)) {
            sysConfigTeachcloudExchangeSerivePath = new SysConfig(sysAdminSetParam.getSchoolId(), SystemConstant.TEACHCLOUD_EXCHANGE_HOST_URL, "第三方统一身份认证", sysAdminSetParam.getTeachcloudExchangeSerivePath());
        } else {
            sysConfigTeachcloudExchangeSerivePath.setConfigValue(sysAdminSetParam.getTeachcloudExchangeSerivePath());
        }
        sysConfigList.add(sysConfigTeachcloudExchangeSerivePath);
        sysConfigService.saveOrUpdateBatch(sysConfigList);

        commonCacheService.updateSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.ACCOUNT_SMS_VERIFY);
        commonCacheService.updateSysConfigCache(sysAdminSetParam.getSchoolId(), SystemConstant.TEACHCLOUD_EXCHANGE_HOST_URL);
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "查询自定义菜单权限")
    @ApiResponses({@ApiResponse(code = 200, message = "菜单权限信息", response = CustomPrivilegeResult.class)})
    @RequestMapping(value = "/menu/custom/list", method = RequestMethod.POST)
    public Result customMenuList() {
        List<PrivilegeDto> customPrivilegeList = sysPrivilegeService.addCustomList();
        return ResultUtil.ok(new CustomPrivilegeResult(customPrivilegeList));
    }

    @ApiOperation(value = "学校新增/修改自定义菜单权限")
    @ApiResponses({@ApiResponse(code = 200, message = "菜单权限信息", response = ResultUtil.class)})
    @RequestMapping(value = "/menu/custom/save", method = RequestMethod.POST)
    @Transactional
    public Result schoolPrivilegeSave(@Valid @RequestBody SysAdminSetParam tSchoolPrivilegeParam, BindingResult bindingResult) throws NoSuchAlgorithmException {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        Set<Long> roleSetIds = null;
        QueryWrapper<TSchoolPrivilege> tSchoolPrivilegeQueryWrapper = new QueryWrapper<>();
        tSchoolPrivilegeQueryWrapper.lambda().eq(TSchoolPrivilege::getSchoolId, tSchoolPrivilegeParam.getSchoolId());
        List<TSchoolPrivilege> tSchoolPrivileges = tSchoolPrivilegeService.list(tSchoolPrivilegeQueryWrapper);
        if (!CollectionUtils.isEmpty(tSchoolPrivileges)) {//编辑
            Set<Long> changePrivilegeSetIds = tSchoolPrivileges.stream().filter(s -> !Arrays.asList(tSchoolPrivilegeParam.getPrivilegeIds()).contains(s.getPrivilegeId()))
                    .collect(Collectors.toList())
                    .stream().map(s -> s.getPrivilegeId())
                    .collect(Collectors.toSet());
            //数据发生改变
            if (!CollectionUtils.isEmpty(changePrivilegeSetIds)) {
                //查询该菜单下所有角色，删除该角色所发生改变的菜单数据
                QueryWrapper<SysRole> sysRoleQueryWrapper = new QueryWrapper<>();
                sysRoleQueryWrapper.lambda().eq(SysRole::getSchoolId, tSchoolPrivilegeParam.getSchoolId());
                List<SysRole> sysRoleList = sysRoleService.list(sysRoleQueryWrapper);

                if (!CollectionUtils.isEmpty(sysRoleList)) {
                    QueryWrapper<SysRolePrivilege> sysRolePrivilegeQueryWrapper = new QueryWrapper<>();
                    sysRolePrivilegeQueryWrapper.lambda()
                            .in(SysRolePrivilege::getRoleId, sysRoleList.stream().map(s -> s.getId()).collect(Collectors.toList()))
                            .in(SysRolePrivilege::getPrivilegeId, changePrivilegeSetIds);
                    List<SysRolePrivilege> sysRolePrivilegeList = sysRolePrivilegeService.list(sysRolePrivilegeQueryWrapper);
                    //仅删除绑定了该权限的角色用户缓存
                    roleSetIds = sysRolePrivilegeList.stream().map(s -> s.getRoleId()).collect(Collectors.toSet());
                    sysRolePrivilegeService.remove(sysRolePrivilegeQueryWrapper);
                }
            }
            tSchoolPrivilegeService.remove(tSchoolPrivilegeQueryWrapper);
        }
        Long[] privilegeIds = tSchoolPrivilegeParam.getPrivilegeIds();
        if (Objects.nonNull(privilegeIds) && privilegeIds.length > 0) {
            List<TSchoolPrivilege> tSchoolPrivilegeList = new ArrayList<>();
            for (int i = 0; i < privilegeIds.length; i++) {
                tSchoolPrivilegeList.add(new TSchoolPrivilege(tSchoolPrivilegeParam.getSchoolId(), privilegeIds[i]));
            }
            tSchoolPrivilegeService.saveBatch(tSchoolPrivilegeList);
        }

        //清缓存
        if (!CollectionUtils.isEmpty(roleSetIds)) {
            for (Long l : roleSetIds) {
                commonCacheService.removeRoleCache(l);
                commonCacheService.removeRolePrivilegeCache(l);
                //绑定该角色的用户都需要清除鉴权缓存
                List<SysUserRole> sysUserRoleList = sysUserRoleService.listByRoleId(l);
                for (SysUserRole s : sysUserRoleList) {
                    SysUser user = commonCacheService.userCache(s.getUserId());
                    if (Objects.nonNull(user)) {
                        commonService.removeUserInfo(s.getUserId(), true);
                    } else {
                        sysUserRoleService.removeById(s);
                    }
                }
            }
        }
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "学校已绑定自定义菜单权限列表")
    @ApiResponses({@ApiResponse(code = 200, message = "菜单权限信息", response = SysAdminSetResult.class)})
    @RequestMapping(value = "/menu/custom/get_school_custom_privileges", method = RequestMethod.POST)
    public Result getSchoolPrivileges(@ApiParam(value = "学校id ", required = true) @RequestParam Long schoolId) {
        List<TSchoolPrivilege> tSchoolPrivilegeList = tSchoolPrivilegeService.findBySchoolId(schoolId);
        List<String> privilegeIdList = tSchoolPrivilegeList.stream().map(s -> String.valueOf(s.getPrivilegeId())).collect(Collectors.toList());
        return ResultUtil.ok(new SysAdminSetResult(schoolId, CollectionUtils.isEmpty(privilegeIdList) ? new ArrayList<>() : privilegeIdList));
    }

    @ApiOperation(value = "查询自定义角色权限")
    @ApiResponses({@ApiResponse(code = 200, message = "角色权限信息", response = CustomPrivilegeResult.class)})
    @RequestMapping(value = "/role/custom/list", method = RequestMethod.POST)
    public Result customRoleList() {
        QueryWrapper<SysRole> sysRoleQueryWrapper = new QueryWrapper<>();
        sysRoleQueryWrapper.lambda().eq(SysRole::getDefaultRole, true)
                .eq(SysRole::getEnable, true)
                .isNull(SysRole::getSchoolId)
                .ne(SysRole::getType, SystemConstant.ADMIN_CODE.toUpperCase())
                .orderByAsc(SysRole::getId);
        List<SysRole> sysRoleList = sysRoleService.list(sysRoleQueryWrapper);
        CustomPrivilegeResult customPrivilegeResult = new CustomPrivilegeResult();
        customPrivilegeResult.setCustomRoleList(sysRoleList);
        return ResultUtil.ok(sysRoleList);
    }

    @ApiOperation(value = "学校新增/修改自定义角色权限")
    @ApiResponses({@ApiResponse(code = 200, message = "角色权限信息", response = ResultUtil.class)})
    @RequestMapping(value = "/role/custom/save", method = RequestMethod.POST)
    @Transactional
    public Result schoolRoleSave(@Valid @RequestBody SysAdminSetParam tSchoolPrivilegeParam, BindingResult bindingResult) throws NoSuchAlgorithmException {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        Set<Long> userSetIds = null;
        QueryWrapper<TSchoolRole> tSchoolRoleQueryWrapper = new QueryWrapper<>();
        tSchoolRoleQueryWrapper.lambda().eq(TSchoolRole::getSchoolId, tSchoolPrivilegeParam.getSchoolId());
        List<TSchoolRole> tSchoolRoles = tSchoolRoleService.list(tSchoolRoleQueryWrapper);
        if (!CollectionUtils.isEmpty(tSchoolRoles)) {//编辑
            Set<Long> changeRoleSetIds = tSchoolRoles.stream().filter(s -> !Arrays.asList(tSchoolPrivilegeParam.getRoleIds()).contains(s.getRoleId()))
                    .collect(Collectors.toList())
                    .stream().map(s -> s.getRoleId())
                    .collect(Collectors.toSet());
            //数据发生改变
            if (!CollectionUtils.isEmpty(changeRoleSetIds)) {
                //查询该角色下所有用户，删除该角色所发生改变的用户数据
                List<SysUserRole> sysUserRoleList = sysUserRoleService.listByRoleIdsAndSchoolId(changeRoleSetIds, tSchoolPrivilegeParam.getSchoolId());

                if (!CollectionUtils.isEmpty(sysUserRoleList)) {
                    List<Long> ids = new ArrayList<>(sysUserRoleList.size());
                    for (SysUserRole s : sysUserRoleList) {
                        userSetIds.add(s.getUserId());
                        ids.add(s.getId());
                    }
                    sysUserRoleService.removeByIds(ids);
                }
            }
            tSchoolRoleService.remove(tSchoolRoleQueryWrapper);
        }
        Long[] roleIds = tSchoolPrivilegeParam.getRoleIds();
        if (Objects.nonNull(roleIds) && roleIds.length > 0) {
            List<TSchoolRole> tSchoolRoleList = new ArrayList<>();
            for (int i = 0; i < roleIds.length; i++) {
                tSchoolRoleList.add(new TSchoolRole(tSchoolPrivilegeParam.getSchoolId(), roleIds[i]));
            }
            tSchoolRoleService.saveBatch(tSchoolRoleList);
        }

        //清缓存
        if (!CollectionUtils.isEmpty(userSetIds)) {
            for (Long l : userSetIds) {
                commonCacheService.removeUserCache(l);
                commonCacheService.removeUserAuthCache(l);
                commonCacheService.removeUserMenuCache(l);
                commonCacheService.removeUserRolePrivilegeCache(l);
            }
        }
        return ResultUtil.ok(true);
    }

    @ApiOperation(value = "学校已绑定自定义角色权限列表")
    @ApiResponses({@ApiResponse(code = 200, message = "角色权限信息", response = SysAdminSetResult.class)})
    @RequestMapping(value = "/role/custom/get_school_custom_roles", method = RequestMethod.POST)
    public Result getSchoolRoles(@ApiParam(value = "学校id ", required = true) @RequestParam Long schoolId) {
        List<TSchoolRole> tSchoolRoleList = tSchoolRoleService.findBySchoolId(schoolId);
        List<String> roleIdList = tSchoolRoleList.stream().map(s -> String.valueOf(s.getRoleId())).collect(Collectors.toList());
        SysAdminSetResult sysAdminSetResult = new SysAdminSetResult();
        sysAdminSetResult.setSchoolId(schoolId);
        sysAdminSetResult.setRoleIdList(CollectionUtils.isEmpty(roleIdList) ? new ArrayList<>() : roleIdList);
        return ResultUtil.ok(sysAdminSetResult);
    }
}
